funcFit2 - A convenient fitting interface
=========================================

funcFit2 is a successor to funcFit, with the goal to resolve the main problems encountered with the original
implementation and maintaining what was convenient about it.

.. note:: funcFit2 is under development. We try to maintain the API, but changes cannot be excluded.

.. toctree::
   :maxdepth: 2

   Tutorial <tutorial1.rst>

   Models <models.rst>
         
   Philosophy <fuf2philo.rst>
